"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_to_regexp_1 = require("path-to-regexp");
const router_1 = require("./router");
class Route {
    constructor(method, path, handler, { exact = false } = {}) {
        this.keys = [];
        this.handle = async (ctx) => {
            return this.handleHandler(this.handler, ctx);
        };
        this.handleHandler = async (handler, ctx) => {
            if (handler instanceof router_1.Router) {
                return handler.handle(ctx);
            }
            else if (Array.isArray(handler)) {
                for (let index = 0; index < handler.length; index++) {
                    const childHandler = handler[index];
                    const returned = await this.handleHandler(childHandler, ctx);
                    if (index === handler.length - 1) {
                        return returned;
                    }
                }
            }
            else {
                return handler(ctx);
            }
        };
        this.method = method;
        this.path = path;
        if (path) {
            this.regex = path_to_regexp_1.pathToRegexp(path, this.keys, { end: exact });
        }
        this.handler = handler;
    }
}
exports.Route = Route;
//# sourceMappingURL=route.js.map